<div align="center">
  <h1 align="center">
    <img src="https://cndaqiang.github.io/wzry.doc/wzry.favicon.png" width="140">
    <br/>
    自动化农活演示
  </h1>
</div>
<div align="center">
  <img alt="autowzry Release" src="https://img.shields.io/github/v/release/cndaqiang/autowzry?style=flat-square&color=ff7fbf&label=Releases" />
  <img alt="Stars" src="https://img.shields.io/github/stars/cndaqiang/autowzry?style=flat-square&color=66bb6a&label=Stars" />
</div>

## 项目简介

[本项目](https://github.com/cndaqiang/autowzry)基于[airtest-mobileauto](https://github.com/cndaqiang/airtest_mobileauto)开发，旨在演示自动化技术。通过图像识别和模拟点击，展示模拟器自动化操作，包括启动模拟器、更新游戏、错误修复、自动对战及礼包领取。本项目重点演示自动化技术在处理重复性任务上的潜力，以及实现7*24h无人值守自动化的方法。目的是为开发者提供技术参考，启发大家探索如何从繁琐的日常操作中解放时间，从而更好地享受生活。技术细节详见 [流程详解](https://autowzry.pages.dev/guide/install/) 和 [备用详解](https://autowzry.cndaqiang.ac.cn/)。


## 免责声明

* 本项目仅为自动化技术演示，旨在展示技术原理和应用，并非游戏辅助工具。
* 请勿使用本项目示例代码或技术方案开发任何违反游戏用户协议的工具或应用。
* 使用本项目或基于本项目开发的内容所产生的一切法律责任由使用者自行承担。
* 请遵守游戏用户协议，避免任何可能影响其他玩家游戏体验的行为。
* 本项目完全免费，请警惕任何收费信息。
* 本项目无任何交流群组，请在[GitHub](https://github.com/cndaqiang/autowzry)交流。




## 致谢
- 灵感和支持来自以下项目:

  - [airtest_mobileauto](https://github.com/cndaqiang/airtest_mobileauto)
  - [WZRY_AirtestIDE](https://github.com/XRSec/WZRY_AirtestIDE)
  - [Airtest Project](https://github.com/AirtestProject)
  - [StarRailAssistant](https://github.com/Starry-Wind/StarRailAssistant)
  - [March7thAssistant](https://github.com/moesnow/March7thAssistant)

- 感谢所有提问issue和为本项目打星的用户!

## 开源协议

该项目采用[GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0.html)许可证进行开源。